geqo.algorithms.algorithms
==========================

.. automodule:: geqo.algorithms.algorithms

   
   .. rubric:: Functions

   .. autosummary::
   
      controlledXGate
      controlledXGateInternal
   
   .. rubric:: Classes

   .. autosummary::
   
      InversePCCM
      InverseQFT
      PCCM
      PermuteQubits
      QFT
      QubitReversal
   